#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.2.0
id: chunked-data-0.2.0-b92c1c54ff991377166d1c34a28deffa
key: chunk_4A1X9LfY5V55deyREe5tMP
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/chunked-data
synopsis: Typeclasses for dealing with various chunked data representations
description:
    Originally present in classy-prelude.
category: Data
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.IOData Data.Textual.Encoding Data.Sequences.Lazy Data.Builder
    Data.ChunkedZip
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
hs-libraries: HSchunked-data-0.2.0-4A1X9LfY5V55deyREe5tMP
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mono-traversable-0.10.2-6786ce4edfbddf2ce2aafd4eb9614140
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
